import React, { ComponentPropsWithoutRef } from 'react';
import { Sizes } from '../../@types';
export interface IIconButtonProps extends ComponentPropsWithoutRef<'button'> {
    /**
     * Defines the background color of button. Can be used for all states of button.
     *
     * Default: "bg-gray-200 active:bg-secondary-900 hover:bg-gray-500"
     */
    bgColor?: string;
    /**
     * Defines the icon color. Use text-color property for it.
     *
     * Default: "text-gray-500 active:text-white hover:text-gray-900"
     */
    iconColor?: string;
    /**
     * Defines if there should be only icon and no background.
     */
    iconOnly?: boolean;
    /**
     * Defines if the button is circular in shape
     */
    isCircular?: boolean;
    /**
     * Defines the size of the button
     *
     * Default: "md"
     */
    size?: keyof typeof Sizes;
    /**
     * Defines if the button is disabled
     */
    disabled?: boolean;
    /**
     * Defines icon type
     *
     * Ex. "font-awesome" or any icon path name.
     */
    iconType: string;
    /**
     * Defines the style and icon it self only if iconType === 'font-awesome'
     */
    iconClass?: string;
}
declare const IconButton: React.ForwardRefExoticComponent<IIconButtonProps & React.RefAttributes<HTMLButtonElement>>;
export default IconButton;
//# sourceMappingURL=IconButton.d.ts.map